searchNodes=[{"doc":"A Phoenix library to generate slug for your schema fieldsExamplesLet's suppose we have a Post schema and we want to generate a slug from title field and save it to the slug field. To achieve that we need to call slugify/2 following the changeset pipeline passing the desireable field. slugify/2 generates the slug and put it to the changeset.defmodule Post do use Ecto.Schema import Ecto.Changeset import Slugy embedded_schema do field(:title, :string) field(:slug, :string) end def changeset(post, attrs) do post |&gt; cast(attrs, [:title, :type]) |&gt; slugify(:title) end endRunning this code on iex console you can see the slug generated as a new change to be persisted.iex&gt; Post.changeset(%Post{}, %{title: &quot;A new Post&quot;}).changes %{title: &quot;A new Post&quot;, slug: &quot;a-new-post&quot;}Slugy just generates a slug if the field's value passed to slugify/2 comes with a new value to persist in attrs (in update cases) or if the struct is a new record to save.","ref":"Slugy.html","title":"Slugy","type":"module"},{"doc":"Returns a downcased dashed string.Examplesiex&gt; Slugy.slugify(&quot;Vamo que vamo&quot;) &quot;vamo-que-vamo&quot;","ref":"Slugy.html#slugify/1","title":"Slugy.slugify/1","type":"function"},{"doc":"The slugify/2 expects a changeset as a first parameter and an atom to the second one. The function will check if there is a change on the &quot;key&quot; field and if affirmative generates the slug and assigns to the slug field, otherwise do nothing and just returns the changeset.iex&gt; Post.changeset(%Post{}, %{title: &quot;A new Post&quot;}).changes %{slug: &quot;a-new-post&quot;, title: &quot;A new Post&quot;}Composed slugIf you need a composed slug e.g. a post title and the type like so &quot;how-to-use-slugy-video&quot; you need to pass the with key that expects a list of atom keys.defmodule Content do use Ecto.Schema import Ecto.Changeset import Slugy embedded_schema do field :name, :string field :type, :string field :slug, :string end def changeset(post, attrs) do post |&gt; cast(attrs, [:name, :type]) |&gt; slugify(with: [:name, :type]) end end iex&gt; Content.changeset(%Content{}, %{name: &quot;Elixir&quot;, type: &quot;video&quot;}).changes %{name: &quot;Elixir&quot;, type: &quot;video&quot;, slug: &quot;elixir-video&quot;}Slugify from a map fieldIn rare cases you need to generate slugs from a field inside a map field that represents a jsonb column on your database.For example by having a struct like below and we want a slug from data -&gt; title:defmodule PostWithMapField do use Ecto.Schema import Ecto.Changeset import Slugy embedded_schema do field :data, :map field :slug, :string end def changeset(post, attrs) do post |&gt; cast(attrs, [:data]) |&gt; slugify([:data, :title]) end endJust pass a list with the keys following the path down to the desirable field.iex&gt; PostWithMapField.changeset(%PostWithMapField{}, %{data: %{title: &quot;This is my AWESOME title&quot;}}).changes %{data: %{title: &quot;This is my AWESOME title&quot;}, slug: &quot;this-is-my-awesome-title&quot;}RoutesAnd lastly if you want to have your routes with the slug as the :id param implement the Phoenix.Param protocol to your slugified schema. Phoenix.Param will extract the slug in place of the :id.defmodule Post do @derive {Phoenix.Param, key: :slug} schema &quot;posts&quot; do # ... end def changeset(post, attrs) do # ... end endFor more information about Phoenix.Param protocol see in https://hexdocs.pm/phoenix/Phoenix.Param.htmlInstallationAdd to your mix.exs file.def deps do [ {:slugy, &quot;~&gt; 4.1.0&quot;} ] endDon’t forget to update your dependencies.$ mix deps.get","ref":"Slugy.html#slugify/2","title":"Slugy.slugify/2","type":"function"}]